# GatorHoldEm
Required libraries:

pip install "python-socketio[client]"

pip install python-socketio

pip install eventlet

Package name on PyPi: 'gatorholdem'

Installation: pip install gatorholdem

